@@ -1,7 +1,7 @@
 package TAPx::Parser::Results;
 
 use strict;
-use vars qw($VERSION);
+use warnings;
 
 use TAPx::Parser::Results::Plan;
 use TAPx::Parser::Results::Test;
@@ -23,14 +23,6 @@ BEGIN {
 
 TAPx::Parser::Results - TAPx::Parser output
 
-=head1 VERSION
-
-Version 0.50_03
-
-=cut
-
-$VERSION = '0.50_03';
-
 =head2 DESCRIPTION
 
 This is merely a factory class which returns an object representing the
@@ -73,10 +65,10 @@ sub new {
     $token                = Data::Dumper::Dumper($token);
 
     # this should never happen!
-    Carp::croak("Could not determine class for\n$token");
+    Carp::croak "Could not determine class for\n$token";
 }
 
-=head2 Boolean methods
+=head3 Boolean methods
 
 The following methods all return a boolean value and are to be overridden in
 the appropriate subclass.
@@ -156,22 +148,4 @@ up.  If you need the original text for the token, see the C<raw> method.
 
 sub as_string { shift->{raw} }
 
-##############################################################################
-
-=head3 C<is_ok>
-
-  if ( $result->is_ok ) { ... }
-
-Reports whether or not a given result has passed.  Anything which is B<not> a
-test result returns true.  This is merely provided as a convenient shortcut.
-
-=cut
-
-sub is_ok { 1 };
-
-sub passed {
-    warn 'passed() is deprecated.  Please use "is_ok()"';
-    goto &is_ok;
-}
-
 1;
