@@ -1,23 +1,13 @@
 package TAPx::Parser::Results::Bailout;
 
 use strict;
-
-use vars qw($VERSION @ISA);
-use TAPx::Parser::Results;
-@ISA = 'TAPx::Parser::Results';
+use warnings;
+use base 'TAPx::Parser::Results';
 
 =head1 NAME
 
 TAPx::Parser::Results::Bailout - Bailout result token.
 
-=head1 VERSION
-
-Version 0.50_03
-
-=cut
-
-$VERSION = '0.50_03';
-
 =head1 DESCRIPTION
 
 This is a subclass of C<TAPx::Parser::Results>.  A token of this class will be
@@ -44,7 +34,7 @@ They keep me awake at night.
 
 =head2 Instance methods
 
-=head3 C<explanation>
+=head3 explanation 
 
   if ( $result->is_bailout ) {
       my $explanation = $result->explanation;
