@@ -1,23 +1,13 @@
 package TAPx::Parser::Results::Comment;
 
 use strict;
-
-use vars qw($VERSION @ISA);
-use TAPx::Parser::Results;
-@ISA = 'TAPx::Parser::Results';
+use warnings;
+use base 'TAPx::Parser::Results';
 
 =head1 NAME
 
 TAPx::Parser::Results::Comment - Comment result token.
 
-=head1 VERSION
-
-Version 0.50_03
-
-=cut
-
-$VERSION = '0.50_03';
-
 =head1 DESCRIPTION
 
 This is a subclass of C<TAPx::Parser::Results>.  A token of this class will be
@@ -56,6 +46,6 @@ Note that this method merely returns the comment preceded by a '# '.
 =cut
 
 sub comment    { shift->{comment} }
-sub as_string  { shift->{raw} }
+sub as_string  { '# ' . shift->{comment} }
 
 1;
