@@ -1,25 +1,13 @@
 package TAPx::Parser::Results::Test;
 
 use strict;
-
-use vars qw($VERSION @ISA);
-use TAPx::Parser::Results;
-@ISA = 'TAPx::Parser::Results';
-
-use vars qw($VERSION);
+use warnings;
+use base 'TAPx::Parser::Results';
 
 =head1 NAME
 
 TAPx::Parser::Results::Test - Test result token.
 
-=head1 VERSION
-
-Version 0.50_03
-
-=cut
-
-$VERSION = '0.50_03';
-
 =head1 DESCRIPTION
 
 This is a subclass of C<TAPx::Parser::Results>.  A token of this class will be
@@ -84,7 +72,7 @@ sub description { shift->{description} }
 
 ##############################################################################
 
-=head3 C<directive>
+=head3 directive
 
   my $directive = $result->directive;
 
@@ -97,7 +85,7 @@ sub directive   { shift->{directive} }
 
 ##############################################################################
 
-=head3 C<explanation>
+=head3 explanation 
 
   my $explanation = $result->explanation;
 
@@ -114,89 +102,38 @@ sub explanation { shift->{explanation} }
 
 ##############################################################################
 
-=head3 C<is_ok>
+=head3 passed
 
-  if ( $result->is_ok ) { ... }
+  if ( $result->passed ) { ... }
 
 Returns a boolean value indicating whether or not the test passed.  Remember
-that for TODO tests, the test always passes.
-
-If the test is unplanned, this method will always return false.  See
-C<is_unplanned>.
+that for TODO tests, the sense of passing and failing is reversed.
 
 =cut
 
-sub is_ok {
+sub passed {
     my $self = shift;
 
-    return if $self->is_unplanned;
     # TODO directives reverse the sense of a test.
-    return $self->has_todo ? 1 : $self->ok !~ /not/;
-}
-
-sub passed {
-    warn 'passed() is deprecated.  Please use "is_ok()"';
-    goto &is_ok;
+    return $self->has_todo ? $self->ok =~ /not/ : $self->ok !~ /not/;
 }
 
 ##############################################################################
 
-=head3 C<is_actual_ok>
+=head3 C<actual_passed>
 
-  if ( $result->is_actual_ok ) { ... }
+  if ( $result->actual_passed ) { ... }
 
 Returns a boolean value indicating whether or not the test passed, regardless
 of its TODO status.
 
 =cut
 
-sub is_actual_ok {
+sub actual_passed {
     my $self = shift;
     return $self->{ok} !~ /not/;
 }
 
-sub actual_passed {
-    warn 'actual_passed() is deprecated.  Please use "is_actual_ok()"';
-    goto &is_actual_ok;
-}
-
-##############################################################################
-
-=head3 C<todo_passed>
-
-  if ( $test->todo_passed ) {
-     # test unexpectedly succeeded
-  }
-
-If this is a TODO test and an 'ok' line, this method returns true.
-Otherwise, it will always return false (regardless of passing status on
-non-todo tests).
-
-This is used to track which tests unexpectedly succeeded.
-
-=cut
-
-sub todo_passed {
-    my $self = shift;
-    return $self->has_todo && $self->is_actual_ok;
-}
-
-##############################################################################
-
-=head3 C<todo_failed>
-
-  # deprecated in favor of 'todo_passed'.  This method was horribly misnamed.
-
-This was a badly misnamed method.  It indicates which TODO tests unexpectedly
-succeeded.  Will now issue a warning and call C<todo_passed>.
-
-=cut
-
-sub todo_failed {
-    warn '"todo_failed" is deprecated.  Please use "todo_passed".  See the docs.';
-    goto &todo_passed;
-}
-
 ##############################################################################
 
 =head3 C<has_skip>
@@ -225,7 +162,7 @@ sub has_todo { 'TODO' eq shift->{directive} }
 
 ##############################################################################
 
-=head3 C<as_string>
+=head3 as_string
 
   print $result->as_string;
 
@@ -253,34 +190,4 @@ sub as_string {
     return $string;
 }
 
-##############################################################################
-
-=head3 C<is_unplanned>
-
-  if ( $test->is_unplanned ) { ... }
-  $test->is_unplanned(1);
-
-If a test number is greater than the number of planned tests, this method will
-return true.  Unplanned tests will I<always> return false for C<is_ok>,
-regardless of whether or not the test C<has_todo>.
-
-Note that if tests have a trailing plan, it is not possible to set this
-property for unplanned tests as we do not know it's unplanned until the plan
-is reached:
-
-  print <<'END';
-  ok 1
-  ok 2
-  1..1
-  END
-
-=cut
-
-sub is_unplanned {
-    my $self = shift;
-    return $self->{unplanned} unless @_;
-    $self->{unplanned} = !!shift;
-    return $self;
-}
-
 1;
