@@ -1,25 +1,13 @@
 package TAPx::Parser::Results::Unknown;
 
 use strict;
-
-use vars qw($VERSION @ISA);
-use TAPx::Parser::Results;
-@ISA = 'TAPx::Parser::Results';
-
-use vars qw($VERSION);
+use warnings;
+use base 'TAPx::Parser::Results';
 
 =head1 NAME
 
 TAPx::Parser::Results::Unknown - Unknown result token.
 
-=head1 VERSION
-
-Version 0.50_03
-
-=cut
-
-$VERSION = '0.50_03';
-
 =head1 DESCRIPTION
 
 This is a subclass of C<TAPx::Parser::Results>.  A token of this class will be
